@@ -4,8 +4,10 @@ pub mod app_api;
 pub mod dict;
 pub mod emit_apple_dict;
 pub mod emit_html;
+mod hk_variant_map_safe;
+pub mod lean_rich_dict;
 pub mod parse;
 pub mod rich_dict;
 pub mod search;
-pub mod lean_rich_dict;
+mod simp_to_trad;
 mod unicode;
